@@ -188,13 +188,16 @@ def try_except(f, require_ipdb=True):
             )
             print(exc_type(message))
             if require_ipdb:
-                import ipdb;
+                import ipdb
                 ipdb.set_trace()
         finally:
             pass
     return handle_problems
 
+
 _ExpType = typing.TypeVar('_ExpType')
+
+
 def dbg(exp: _ExpType) -> _ExpType:
     """
     The code from https://github.com/tylerwince/pydbg
@@ -202,7 +205,7 @@ def dbg(exp: _ExpType) -> _ExpType:
     Call dbg with any variable or expression.
     Calling dbg will print to stderr the current filename and lineno,
     as well as the passed expression and what the expression evaluates to:
-    
+
     Examples
     --------
     >>> a = 2
@@ -211,13 +214,13 @@ def dbg(exp: _ExpType) -> _ExpType:
     >>> def square(x: int) -> int:
     >>>     return x * x
     >>> dbg(square(a))
-    
+
     """
     for frame in inspect.stack():
         line = frame.code_context[0]
         if "dbg" in line:
             start = line.find('(') + 1
-            end =  line.rfind(')')
+            end = line.rfind(')')
             if end == -1:
                 end = len(line)
             print(
@@ -227,3 +230,59 @@ def dbg(exp: _ExpType) -> _ExpType:
             break
 
     return exp
+
+
+def now(fmt='%Y-%m-%d %H:%M:%S'):
+    """get today's date based on the format
+
+    Parameters
+    ----------
+    fmt : str, optional
+        the date format, by default '%Y-%m-%d'
+
+    Returns
+    -------
+    str
+        the string of today
+    """
+    return datetime.now().strftime(fmt)
+
+
+def sizeof_fmt(num, suffix="B"):
+    """format the size
+
+    Parameters
+    ----------
+    num : int
+        the size value
+    suffix : str, optional
+        the suffix, by default "B"
+
+    Returns
+    -------
+    str
+        the human-readable string
+    """
+
+    a = 5
+    for unit in ["", "Ki", "Mi", "Gi", "Ti", "Pi", "Ei", "Zi"]:
+        if abs(num) < 1024.0:
+            return "%3.1f %s%s" % (num, unit, suffix)
+        num /= 1024.0
+    return "%.1f %s%s" % (num, "Yi", suffix)
+
+
+def get_var_size(var):
+    """get the size of variable
+
+    Parameters
+    ----------
+    var : any variable
+        the variable in globales()
+
+    Returns
+    -------
+    str
+        the size of variable
+    """
+    return sizeof_fmt(sys.getsizeof(var))
